.. _pydl.goddard:

==================================
Goddard Utilities (`pydl.goddard`)
==================================

Introduction
++++++++++++

This is a placeholder for Goddard Utilities documentation.

API
+++

.. automodapi:: pydl.goddard

.. automodapi:: pydl.goddard.astro

.. automodapi:: pydl.goddard.math

.. automodapi:: pydl.goddard.misc
